Documentation
¶
Index ¶
- Constants
- func GlobalConfigDirPath() string
- func GlobalConfigPath() string
- type Paths
- func (p *Paths) BoardConfigPath(boardName string) string
- func (p *Paths) BoardDir(boardName string) string
- func (p *Paths) BoardsRoot() string
- func (p *Paths) CardPath(boardName, cardID string) string
- func (p *Paths) CardsDir(boardName string) string
- func (p *Paths) CustomFaviconPath() string
- func (p *Paths) KanRoot() string
- func (p *Paths) ProjectConfigPath() string
Constants ¶
const ( DefaultKanDir = ".kan" BoardsDir = "boards" CardsDir = "cards" ConfigFileName = "config.toml" GlobalConfigDir = ".config/kan" CustomFaviconFile = "favicon.svg" )
Variables ¶
This section is empty.
Functions ¶
func GlobalConfigDirPath ¶
func GlobalConfigDirPath() string
GlobalConfigDir returns the directory for global config.
func GlobalConfigPath ¶
func GlobalConfigPath() string
GlobalConfigPath returns the path to the global config file.
Types ¶
type Paths ¶
type Paths struct {
// contains filtered or unexported fields
}
Paths provides path resolution for Kan data files.
func (*Paths) BoardConfigPath ¶
BoardConfigPath returns the config file path for a board.
func (*Paths) BoardsRoot ¶
BoardsRoot returns the boards directory.
func (*Paths) CustomFaviconPath ¶ added in v0.8.0
CustomFaviconPath returns the path to a custom favicon file.
func (*Paths) ProjectConfigPath ¶ added in v0.8.0
ProjectConfigPath returns the path to the project config file.
Click to show internal directories.
Click to hide internal directories.