Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewTestPaths ¶
NewTestPaths creates a Paths for testing with the given temp directory.
func TempGitRepo ¶
TempGitRepo creates a temporary git repository for testing. Returns the repo path and a cleanup function.
func TempKanDir ¶
TempKanDir creates a temporary directory with a .kan structure for testing. Returns the temp dir path and a cleanup function.
func TestBoardConfig ¶
func TestBoardConfig(name string) *model.BoardConfig
TestBoardConfig returns a board config with sensible test defaults.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.