Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type App ¶
type App struct {
GitClient *git.Client
GlobalStore store.GlobalStore
Paths *config.Paths
BoardStore store.BoardStore
CardStore store.CardStore
Prompter prompt.Prompter
InitService *service.InitService
BoardService *service.BoardService
CardService *service.CardService
AliasService *service.AliasService
BoardResolver *resolver.BoardResolver
CardResolver *resolver.CardResolver
ProjectRoot string
}
App holds all the dependencies for the CLI. Uses interfaces for testability.
func NewApp ¶
NewApp creates a new App with all dependencies wired up. If interactive is false, uses NoopPrompter that fails on prompts.
func (*App) GetCreator ¶
GetCreator returns the username for the card creator field.
func (*App) RequireKan ¶
RequireKan ensures Kan is initialized in the current project.
type CommandContext ¶
type CommandContext struct {
// Global flags
NonInteractive *bool
// init command
InitUsed *bool
InitLocation *string
// board command
BoardUsed *bool
BoardCreateUsed *bool
BoardCreateName *string
BoardListUsed *bool
// add command
AddUsed *bool
AddTitle *string
AddDescription *string
AddBoard *string
AddColumn *string
AddParent *string
AddFields *[]string
// show command
ShowUsed *bool
ShowCard *string
ShowBoard *string
// list command
ListUsed *bool
ListBoard *string
ListColumn *string
// edit command
EditUsed *bool
EditCard *string
EditBoard *string
EditTitle *string
EditDescription *string
EditColumn *string
EditParent *string
EditAlias *string
EditFields *[]string
// serve command
ServeUsed *bool
ServePort *int
ServeNoOpen *bool
// migrate command
MigrateUsed *bool
MigrateDryRun *bool
}
CommandContext holds parsed values and used flags for all commands.
Click to show internal directories.
Click to hide internal directories.