config

package
v0.6.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 7, 2026 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

const (
	DefaultKanDir   = ".kan"
	BoardsDir       = "boards"
	CardsDir        = "cards"
	ConfigFileName  = "config.toml"
	GlobalConfigDir = ".config/kan"
)

Variables

This section is empty.

Functions

func GlobalConfigDirPath

func GlobalConfigDirPath() string

GlobalConfigDir returns the directory for global config.

func GlobalConfigPath

func GlobalConfigPath() string

GlobalConfigPath returns the path to the global config file.

Types

type Paths

type Paths struct {
	// contains filtered or unexported fields
}

Paths provides path resolution for Kan data files.

func NewPaths

func NewPaths(projectRoot string, dataLocation string) *Paths

NewPaths creates a new Paths resolver for the given project.

func (*Paths) BoardConfigPath

func (p *Paths) BoardConfigPath(boardName string) string

BoardConfigPath returns the config file path for a board.

func (*Paths) BoardDir

func (p *Paths) BoardDir(boardName string) string

BoardDir returns the directory for a specific board.

func (*Paths) BoardsRoot

func (p *Paths) BoardsRoot() string

BoardsRoot returns the boards directory.

func (*Paths) CardPath

func (p *Paths) CardPath(boardName, cardID string) string

CardPath returns the file path for a specific card.

func (*Paths) CardsDir

func (p *Paths) CardsDir(boardName string) string

CardsDir returns the cards directory for a board.

func (*Paths) KanRoot

func (p *Paths) KanRoot() string

KanRoot returns the root directory for Kan data.

Jump to