Documentation
¶
Index ¶
Constants ¶
const ( DefaultKanDir = ".kan" BoardsDir = "boards" CardsDir = "cards" ConfigFileName = "config.toml" GlobalConfigDir = ".config/kan" )
Variables ¶
This section is empty.
Functions ¶
func GlobalConfigDirPath ¶
func GlobalConfigDirPath() string
GlobalConfigDir returns the directory for global config.
func GlobalConfigPath ¶
func GlobalConfigPath() string
GlobalConfigPath returns the path to the global config file.
Types ¶
type Paths ¶
type Paths struct {
// contains filtered or unexported fields
}
Paths provides path resolution for Kan data files.
func (*Paths) BoardConfigPath ¶
BoardConfigPath returns the config file path for a board.
func (*Paths) BoardsRoot ¶
BoardsRoot returns the boards directory.
Click to show internal directories.
Click to hide internal directories.