git

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 4, 2026 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Client

type Client struct{}

Client provides git operations.

func NewClient

func NewClient() *Client

NewClient creates a new git client.

func (*Client) GetRepoRoot

func (c *Client) GetRepoRoot() (string, error)

GetRepoRoot returns the repository root directory. Returns an error if not in a git repository.

func (*Client) GetUserName

func (c *Client) GetUserName() (string, error)

GetUserName returns the configured git user.name.

func (*Client) IsRepo

func (c *Client) IsRepo() bool

IsRepo returns true if the current directory is inside a git repository.

Jump to