testutil

package
v0.10.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 31, 2026 License: Apache-2.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewTestPaths

func NewTestPaths(baseDir string) *config.Paths

NewTestPaths creates a Paths for testing with the given temp directory.

func TempGitRepo

func TempGitRepo(t *testing.T) (string, func())

TempGitRepo creates a temporary git repository for testing. Returns the repo path and a cleanup function.

func TempKanDir

func TempKanDir(t *testing.T) (string, func())

TempKanDir creates a temporary directory with a .kan structure for testing. Returns the temp dir path and a cleanup function.

func TestBoardConfig

func TestBoardConfig(name string) *model.BoardConfig

TestBoardConfig returns a board config with sensible test defaults.

func TestCard

func TestCard(id, title string) *model.Card

TestCard returns a card with sensible test defaults.

Types

This section is empty.

Jump to